pytest-instafail
================

|build status|_

.. |build status| image:: https://github.com/pytest-dev/pytest-instafail/actions/workflows/test.yml/badge.svg
   :alt: Build Status
.. _build status: https://github.com/pytest-dev/pytest-instafail/actions/workflows/test.yml

pytest-instafail is a plugin for `pytest <https://pytest.org>`_ that shows
failures and errors instantly instead of waiting until the end of test session.

Requirements
------------

You will need the following prerequisites in order to use pytest-instafail:

- Python 3.7+ or PyPy3
- pytest 5 or newer

Installation
------------

To install pytest-instafail::

    $ pip install pytest-instafail

Then run your tests with::

    $ pytest --instafail

Resources
---------

- `Issue Tracker <https://github.com/pytest-dev/pytest-instafail/issues>`_
- `Code <https://github.com/pytest-dev/pytest-instafail/>`_
- `Development Version
  <https://github.com/pytest-dev/pytest-instafail/zipball/master#egg=pytest-instafail-dev>`_
